# Version 0.7.0. What's new?

The version number is synchronized with the version of labmate.

## Quickly:

1. **Syntax highlighting**: Code now looks much nicer with the implementation of GitHub-style syntax highlighting.
2. **Easier navigation**: Outline of the sections inside the data.
3. **Find inside the text**: Use shortcut ctrl+F to find anything inside the text.
4. **Mermaid preview**: The app now provides a preview of Mermaid diagrams. The preview is generated by opening an HTML page in your browser, ensuring a lightweight application.

## Easier navigation

Now data that ends with "\*.py" are looked for sections.
To put a new section use comments like:

```python
# ====== Section 1 ======
```

The pattern used for search is `# *={3,} *([\\w ]*) *={3,}`. Therefore, following types of comments are also possible:

```python
# ==== Section 1 ====
#      ===========   Section 1   ==========
```

## Minor features

- Keys are sorted
